<?php

namespace Drupal\mcapi_signatures\Plugin\Block;
use Drupal\mcapi\Plugin\Block\WalletContextBlockBase;
use Drupal\user\Entity\User;
use Drupal\user\UserInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Render\Markup;

/**
 * Provides a block for switching users.
 *
 * @Block(
 *   id = "mcapi_pending",
 *   admin_label = @Translation("Pending transactions"),
 *   category = "Community accounting"
 * )
 */
class Pending extends WalletContextBlockBase implements ContainerFactoryPluginInterface {

  /**
   * {@inheritdoc}
   */
  public function label() {
    if ($this->configuration['holder_source'] == static::HOLDER_CURRENT_USER) {
      $label = $this->t('Pending transactions');
    }
    else {
      // only the settings page should have no holder.
      $owner = isset($this->holder) ? $this->getWalletOwner()->getDisplayName() : '[user:display-name]';
      $label = $this->t('Pending transactions for @name', ['@name' => $owner]);
    }
    return $label;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return parent::defaultConfiguration() + [
      'empty_message' => $this->t('No pending transactions.')
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, $form_state) {
    $form = parent::blockForm($form, $form_state);
    $form['empty_message'] = [
      '#title' => $this->t('Empty message'),
      '#description' => $this->t('leave blank to hide the block when there are no pending transactions'),
      '#type' => 'textfield',
      '#default_value' => $this->configuration['empty_message'],
      '#placeholder' => $this->t('No pending transactions.')
    ];
    return $form;
  }


  private function getWalletOwner() : User {
    if ($this->holder instanceOf UserInterface) {
      $owner = $this->holder;
    }
    else {
      $owner = $this->holder->getOwner();
    }
    return $owner;
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    $renderable = [];
    $uid = $this->getWalletOwner()->id();
    $waiting_on_me = signature_needed_of_me($uid);
    $i_wait_for = signature_needed_of_other($uid);
    if ($serials = array_merge($waiting_on_me, $i_wait_for)) {
      // Just to be safe, check that they exist in the transaction table.
      $serials = \Drupal::database()->select('mcapi_transaction', 't')->fields('t', ['serial'])->condition('serial', $serials, 'IN')->execute()->fetchCol();
      $renderable = mcapi_render_sentences($serials, TRUE);
    }
    elseif ($this->configuration['empty_message']) {
      // @todo put an optional empty message
      $renderable[] = [
        '#markup' => Markup::create($this->configuration['empty_message']),
        '#weight' => -1
      ];
    }

    return $renderable += parent::build();
  }

}

