<?php

namespace Drupal\mcapi\Plugin\Action;

use Drupal\mcapi\Plugin\TransactionActionBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Canonical viewing of a transaction.
 *
 * @Action(
 *   id = "mcapi_transaction.view_action",
 *   label = @Translation("View a transaction"),
 *   type = "mcapi_transaction"
 * )
 *
 */
class View extends TransactionActionBase {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $elements = parent::buildConfigurationForm($form, $form_state);
    // @see mcapi_query_mcapi_transaction_access_alter().
    $elements['access']['#description'] .= ' '.$this->t("These settings affect views listings for users who do NOT have permission to 'view all transactions'. Check the fewest options necessary for better performance.");

    unset($elements['sure']['#type']);
    $elements['sure']['format']['#value'] = 'twig';
    $elements['sure']['format']['#type'] = 'hidden';

    // @todo enable this with tokens
    $elements['sure']['page_title']['#access'] = FALSE;
    $elements['sure']['format']['#access'] = FALSE;
    $elements['sure']['button']['#access'] = FALSE;
    $elements['sure']['cancel_link']['#access'] = FALSE;
    $elements['message']['#access'] = FALSE;
    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function access($object, AccountInterface $account = NULL, $return_as_object = FALSE) {
    $result = parent::access($object, $account, $return_as_object);

    return $return_as_object ?
      $result->addCacheableDependency($object)->cachePerUser() :
      $result;
  }

}
