<?php

namespace Drupal\mcapi\Plugin\Block;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Entity\EntityDisplayRepositoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Displays all the wallets of an entity.
 *
 * Entity being either the current user OR the entity being viewed. Shows the
 * wallet view mode 'mini'.
 *
 * @Block(
 *   id = "mcapi_wallet",
 *   admin_label = @Translation("View of entity's wallets"),
 *   category = @Translation("Community Accounting")
 * )
 */
class WalletView extends WalletContextBlockBase {

    public function __construct(array $configuration, $plugin_id, $plugin_definition, $entityTypeManager, $currentUser, $request,  EntityDisplayRepositoryInterface $entity_display_repository) {
      parent::__construct($configuration, $plugin_id, $plugin_definition, $entityTypeManager, $currentUser, $request);
      $this->entityDisplayRepository = $entity_display_repository;
    }

  /**
   * Injection.
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('current_user'),
      $container->get('request_stack')->getCurrentRequest(),
      $container->get('entity_display.repository')
    );
  }


  public function defaultConfiguration() {
    $conf = parent::defaultConfiguration();
    $conf['view_mode'] = 'summary';// if this doesn't exist, it'll fall back I'm sure
    return $conf;
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    $form['view_mode'] = [
      '#title' => $this->t('View mode'),
      '#type' => 'radios',
      '#options' => $this->entityDisplayRepository->getViewModeOptions('mcapi_wallet'),
      '#default_value' => $this->configuration['view_mode']
    ];
    unset($form['view_mode']['#options']['token']);
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $renderable = $this->entityTypeManager
      ->getViewBuilder('mcapi_wallet')
      ->viewMultiple($this->getWallets(), $this->configuration['view_mode']);
    return $renderable += parent::build();
  }

}
