<?php

namespace Drupal\mcapi\Plugin;

use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\mcapi\Entity\TransactionInterface;
use Drupal\system\Entity\Action;

/**
 * Plugin manager for transaction relatives.
 */
class TransactionRelativeManager extends DefaultPluginManager {

  /**
   * Constructor.
   */
  public function __construct($namespaces, $cache_backend, $module_handler) {
    parent::__construct(
      'Plugin/TransactionRelative',
      $namespaces,
      $module_handler,
      '\Drupal\mcapi\Plugin\TransactionRelativeInterface',
      '\Drupal\mcapi\Annotation\TransactionRelative'
    );
    // don't know if this is important.
    $this->setCacheBackend($cache_backend, 'transaction_relatives');
  }

  /**
   * Get the active transaction relative plugins.
   * return TransactionRelativeInterface[]
   */
  public function getActivePlugins(string $transaction_action_name) : array {
    $action_access_relatives = Action::load('transaction_'.$transaction_action_name)
      ->getPlugin()
      ->getConfiguration()['access'];

    $plugins = [];
    foreach (array_filter($action_access_relatives) as $id) {
      $plugins[$id] = $this->createInstance($id);
    }
    // If the plugins had a weight we would sort them here.
    return $plugins;
  }

  /**
   * Get the names of the config items.
   *
   * @return array
   *   The names of all the plugins, keyed by ID.
   */
  public function options(): array {
    foreach ($this->getDefinitions() as $id => $def) {
      // Is this translated?
      $names[$id] = $def['label'];
    }
    return $names;
  }

  /**
   * {@inheritdoc}
   */
  public function getUsers(TransactionInterface $transaction, array $plugin_names) : array {
    // Get the plugins.
    $user_ids = [];
    foreach ($plugin_names as $plugin_id) {
      $user_ids = array_merge($user_ids, $this->createInstance($plugin_id)->getUsers($transaction));
    }
    return array_unique($user_ids);
  }

  /**
   * {@inheritdoc}
   */
  public function isRelative($transaction, $account, array $relatives) : bool {
    if (!$account) {
      $account = \Drupal::currentUser();
    }
    foreach (array_filter($relatives) as $plugin_id) {
      if ($this->createInstance($plugin_id)->isRelative($transaction, $account)) {
        return TRUE;
      }
    }
    return FALSE;
  }

}
