<?php

namespace Drupal\mcapi\Plugin\views\cache;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerTrait;
use Drupal\views\Plugin\views\cache\Tag;

/**
 * Simple caching of query results for Views displays.
 *
 * @ingroup views_cache_plugins
 *
 * @ViewsCache(
 *   id = "wallet_arg",
 *   title = @Translation("Cache per wallet"),
 *   help = @Translation("Tag based caching of data. Caches will persist until any related cache tags are invalidated.")
 * )
 */
class WalletArg extends Tag {

  /**
   * {@inheritdoc}
   */
  public function summaryTitle() {
    return $this->t('Per wallet');
  }

  /**
   * {@inheritdoc}
   *
   * This could also be made to work with exposed filters
   */
  public function getCacheTags() {
    // Which of the args is the payer or payee arg?
    $display_name = $this->view->current_display;
    $args = $this->view->getDisplay()->getHandlers('argument');
    $map = array_keys($args);
    foreach ($args as $fieldname => $arg) {
      // Not quite sure where the dot comes from. is there a missing alias?
      if ($fieldname == 'payer' or $fieldname == 'payee') {
        $index = array_search($fieldname, $map);
        break;
      }
    }
    if (isset($index)) {
      return ['mcapi_wallet:'.$this->view->args[$index]];
    }
    // Info for the developer.
    \Drupal::logger('mcapi')->error('Views per-wallet plugin needs payer or payee contextual filter');
    return [];
  }

}
